## Description
Brief description of what this PR does.

## Type of change
- [ ] Bug fix
- [ ] New feature
- [ ] Breaking change
- [ ] Documentation update

## Checklist
- [ ] My code follows the style guidelines of this project
- [ ] I have performed a self-review of my code
- [ ] I have added tests that prove my fix is effective or that my feature works
- [ ] All tests pass locally (`uv run pytest`)
- [ ] I have run linting (`uv run ruff check src/`)
- [ ] I have run type checking (`uv run pyright src`)